@@ -68,9 +68,10 @@ class InvoiceAppliedTaxes(BaseResponseModel):
 
 class InvoiceResponse(BaseResponseModel):
     lago_id: str
-    sequential_id: int
+    sequential_id: Optional[int]
     number: str
     issuing_date: Optional[str]
+    payment_dispute_lost_at: Optional[str]
     payment_due_date: Optional[str]
     net_payment_term: int
     invoice_type: str
